summaryrefslogtreecommitdiffstats
path: root/src/gui/editors/notation/NotationView.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/editors/notation/NotationView.h')
-rw-r--r--src/gui/editors/notation/NotationView.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/gui/editors/notation/NotationView.h b/src/gui/editors/notation/NotationView.h
index 236b89b..461d299 100644
--- a/src/gui/editors/notation/NotationView.h
+++ b/src/gui/editors/notation/NotationView.h
@@ -114,18 +114,18 @@ class NotationView : public EditView,
public:
explicit NotationView(RosegardenGUIDoc *doc,
std::vector<Segment *> segments,
- TQWidget *tqparent,
+ TQWidget *parent,
bool showProgressive); // update during initial render?
/**
* Constructor for printing only. If tqparent is provided, a
* progress dialog will be shown -- otherwise not. If another
* NotationView is provided, the fonts and other settings used
* for printing will be taken from that view.
*/
explicit NotationView(RosegardenGUIDoc *doc,
std::vector<Segment *> segments,
- TQWidget *tqparent,
+ TQWidget *parent,
NotationView *referenceView);
~NotationView();
@@ -114,18 +114,18 @@ class NotationView : public EditView,
bool showProgressive); // update during initial render?
/**
- * Constructor for printing only. If tqparent is provided, a
+ * Constructor for printing only. If parent is provided, a
* progress dialog will be shown -- otherwise not. If another
* NotationView is provided, the fonts and other settings used